@@ -551,7 +551,7 @@ class ShakenStiSpConfResource(DnlResource):
     @staticmethod
     def validate_x5u(x5u):
         try:
-            if x5u.startswith('http') and x5u.endswith('.crt'):
+            if x5u.startswith('http'):
                 return True
             else:
                 log.warning('Certificate not valid. {}'.format(x5u))
